% This is an example configuration file that provides a `less' emulation 
% for MOST.
%
% The format is simple: 
%       setkey <function-name> <key-name>
%       unsetkey <key-name>
%       color <object-name> <fg> <bg>
%
% Here <key-name> must be enclosed in double quotes.  '^' represents Ctrl.
% The function name is not in double quotes.
% 
%
% When MOST starts up, it looks for a keymap file given by the environment 
% variable MOST_INITFILE.  If that environment variable does not exist, 
% MOST will look in the users HOME directory for .mostrc on Unix systems
% and MOST.RC on VMS systems.
%
% The file `most.rc' contains a listing of the default MOST keybindings.

% Color settings

color normal lightgray black
color status yellow blue
color underline brightgreen black
color overstrike brightred black

% Keybindings

unsetkey "^K"
setkey up "^K"

unsetkey ":"
setkey next_file ":n"
setkey find_file ":e"
setkey next_file ":p"
setkey toggle_options ":o"
setkey toggle_case ":c"
setkey delete_file ":d"
setkey exit ":q"

setkey down "e"
setkey down "E"
setkey down "j"
setkey down "^N"
setkey up "y"
setkey up "^Y"
setkey up "k"
setkey up "^P"
setkey page_down "f"
setkey page_down "^F"
setkey page_up "b"
setkey page_up "^B"
setkey other_window "z"
setkey other_window "w"
setkey search_backward "?"
setkey bob "p"
setkey goto_mark "'"
setkey find_file "E"
setkey edit "v"
